@@ -25,8 +25,7 @@ Ext.define('MP.data.MetaData', {
         'Ext.data.Store',
         'Ext.data.proxy.Ajax',
         'Ext.data.reader.Json',
-        'Ext.util.MixedCollection',
-        'MP.grid.column.CheckColumn'
+        'Ext.util.MixedCollection'
     ],
 
     statics: {
